<?php

namespace Netmon\Devices\Serializers;

use Gate;

use Netmon\JsonApi\Serializers\BasicSerializer;

use Netmon\Devices\Models\DeviceStatus;

class DeviceStatusSerializer extends BasicSerializer
{
    protected $type = 'deviceStatuses';

    public function getAttributes($model, array $fields = null)
    {
        if (! ($model instanceof DeviceStatus)) {
            throw new \InvalidArgumentException(
                get_class($this).' can only serialize instances of '.DeviceStatus::class
            );
        }

        // set up attributes
        $attributes = $model->getAttributes();
        $attributes['created_at']  = $this->formatDate($model->created_at);
        $attributes['updated_at'] = $this->formatDate($model->updated_at);

        return $attributes;
    }

    public function getLinks($model) {
        //links to always include in the resource
        $links = [
            'self' => config('app.url')."/device_statuses/{$model->id}",
        ];

        //links to include based permissions
        if(Gate::allows('show', $model))
            $links['read'] = config('app.url')."/device_statuses/{$model->id}";
        if(Gate::allows('update', $model))
            $links['update'] = config('app.url')."/device_statuses/{$model->id}";
        if(Gate::allows('destroy', $model))
            $links['delete'] = config('app.url')."/device_statuses/{$model->id}";

        return $links;
    }

    /**
     * @return \Tobscure\JsonApi\Relationship
     */
    protected function device($model)
    {
        return $this->belongsTo($model, DeviceSerializer::class);
    }
}

?>
