<?php

namespace Netmon\Devices\Tests;

use Netmon\Server\Tests\ModuleTestCase;
use Artisan;

class WorkflowTest extends ModuleTestCase
{
    protected function moduleServiceProvider() {
        return \Netmon\Devices\ModuleServiceProvider::class;
    }

    public function testWorkflow() {
        // Create user one. This is the user who will be the owner
        // of the device at the end of the process
        $user1['name'] = "firstuser";
        $user1['password'] = "testtest";
		$this->json(
			'POST',
			'/users',
			[
				'data' => [
					'type' => "user",
					'attributes' => [
						'name' => $user1['name'],
						'password' => $user1['password']
					]
				]
			]
		);
		$this->assertResponseStatus(201);
        $user1['id'] = json_decode($this->response->getContent())->data->id;

        // Create user two. This will be the user generated by
        // the software running on the user
        $user2['name'] = "387tbr23679bw";
        $user2['password'] = "l2zi2t3bqwedh";
		//create second user, should have default roles
		$this->json(
			'POST',
			'/users',
			[
				'data' => [
					'type' => "user",
					'attributes' => [
						'name' => $user2['name'],
						'password' => $user2['password']
					]
				]
			]
		);
		$this->assertResponseStatus(201);

        // Get auth token for user two
		$this->json(
			'POST',
			'/auth-token',
			[
				'data' => [
					'type' => "auth-token-request",
					'attributes' => [
						'username' => $user2['name'],
						'password' => $user2['password']
					]
				]
			]
		);
		$this->assertResponseStatus(201);

        // Create an auth token for user two so he can create the device.
        // A user who creates a device does not have to be the owner
        // of the device. But he will get read/write permissions
        // on the device
        $data = json_decode($this->response->getContent())->data;
        $headers = ['Authorization' => 'Bearer '.$data->attributes->token];
        $this->json(
			'POST',
			'/devices',
			[
				'data' => [
					'type' => "device",
					'attributes' => [
						'hostname' => "test.ffnw.de"
					]
				]
			],
            $headers
		);
		$this->assertResponseStatus(201);

/*        $this->json(
			'GET',
			'/device_authorizations',
            $headers
		);
        dd($this->response->getContent());*/


        // Now we create a new device authorization.
        // This will allow the real user (user one) to become the owner
        // of the device using the webinterface and a password that
        // can be the mac address of the router i.e..
        $deviceId = json_decode($this->response->getContent())->data->id;
        $authorizationPassword = "ZB:MA:CA:DR:ES:SE";
        $this->json(
			'POST',
			'/device-authorizations',
			[
				'data' => [
					'type' => "device_authorization",
					'attributes' => [
						'device_id' => $deviceId,
                        'type' => 'ownership',
                        'password' => $authorizationPassword
					]
				]
			],
            $headers
		);
		$this->assertResponseStatus(201);

        // Now we simulate to become the owner of the device by
        // providing the correct password and our user_id
        $this->json(
			'POST',
			'/device-authorizations',
			[
				'data' => [
					'type' => "device_authorization",
					'attributes' => [
						'device_id' => $deviceId,
                        'type' => 'ownership',
                        'password' => $authorizationPassword,
                        'user_id' => $user1['id']
					]
				]
			]
		);
		$this->assertResponseStatus(204);

        // Are we owner now? Yes we are!
        $this->json(
			'GET',
			"/devices/{$deviceId}"
		);
        $ownerId = json_decode($this->response->getContent())->data->attributes->owner_id;
		$this->assertEquals($ownerId, $user1['id']);
	}
}
?>
